==> pdt-Update-3.1.2.201212211235.zip: org/eclipse/php/internal/debug/core/zend/debugger/messages/GetCWDResponse.java <==
/*******************************************************************************
 * Copyright (c) 2009 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *     Zend Technologies
 *******************************************************************************/
/*
 * EvalResponse.java
 *
 */

package org.eclipse.php.internal.debug.core.zend.debugger.messages;

import java.io.DataInputStream;
import java.io.DataOutputStream;
import java.io.IOException;

import org.eclipse.php.debug.core.debugger.messages.IDebugResponseMessage;
import org.eclipse.php.internal.debug.core.zend.communication.CommunicationUtilities;

/**
 * @author michael
 */
public class GetCWDResponse extends DebugMessageResponseImpl implements
		IDebugResponseMessage {

	private String cwd;

	/**
	 * Sets the result.
	 */
	public void setCWD(String cwd) {
		this.cwd = cwd;
	}

	/**
	 * Returns the result
	 */
	public String getCWD() {
		return cwd;
	}

	public void deserialize(DataInputStream in) throws IOException {
		setID(in.readInt());
		setStatus(in.readInt());
		setCWD(CommunicationUtilities.readString(in));
	}

	public int getType() {
		return 1036;
	}

	public void serialize(DataOutputStream out) throws IOException {
		out.writeShort(getType());
		out.writeInt(getID());
		out.writeInt(getStatus());
		CommunicationUtilities.writeString(out, getCWD());
	}
}

==> pdt-Update-6.0.0.201806122250.zip: org/eclipse/php/internal/debug/core/zend/debugger/messages/GetCWDResponse.java <==
/*******************************************************************************
 * Copyright (c) 2009 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *     Zend Technologies
 *******************************************************************************/
/*
 * EvalResponse.java
 *
 */

package org.eclipse.php.internal.debug.core.zend.debugger.messages;

import java.io.DataInputStream;
import java.io.DataOutputStream;
import java.io.IOException;

import org.eclipse.php.debug.core.debugger.messages.IDebugResponseMessage;
import org.eclipse.php.internal.debug.core.zend.communication.CommunicationUtilities;

/**
 * @author michael
 */
public class GetCWDResponse extends DebugMessageResponseImpl implements IDebugResponseMessage {

	private String cwd;

	/**
	 * Sets the result.
	 */
	public void setCWD(String cwd) {
		this.cwd = cwd;
	}

	/**
	 * Returns the result
	 */
	public String getCWD() {
		return cwd;
	}

	@Override
	public void deserialize(DataInputStream in) throws IOException {
		setID(in.readInt());
		setStatus(in.readInt());
		setCWD(CommunicationUtilities.readString(in));
	}

	@Override
	public int getType() {
		return 1036;
	}

	@Override
	public void serialize(DataOutputStream out) throws IOException {
		out.writeShort(getType());
		out.writeInt(getID());
		out.writeInt(getStatus());
		CommunicationUtilities.writeString(out, getCWD());
	}
}
